if __name__ == '__main__':
    import sys
    import Pyro4.configuration

    sys.exit(Pyro4.configuration.main())
